==> nextcloud-php72-19.0.3.txz: usr/local/www/nextcloud/apps-pkg/files_sharing/l10n/fi.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Jaettu kanssasi",
    "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
    "Files and folders others share with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
    "Shared with others" : "Jaettu muiden kanssa",
    "Nothing shared yet" : "Ei mitään jaettua",
    "Files and folders you share will show up here" : "Jakamasi tiedostot ja kansiot näkyvät täällä",
    "Shared by link" : "Jaettu linkin kautta",
    "No shared links" : "Ei jaettuja linkkejä",
    "Files and folders you share by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
    "Deleted shares" : "Poistetut jaot",
    "No deleted shares" : "Ei poistettuja jakoja",
    "Shares you deleted will show up here" : "Poistamasi jaot näkyvät täällä",
    "Pending shares" : "Odottavat jaot",
    "No pending shares" : "Ei odottavia jakoja",
    "Shares you have received but not confirmed will show up here" : "Vastaanottamasi jaot, joita ei ole vahvistettu, näkyvät täällä",
    "Shares" : "Jaot",
    "No shares" : "Ei jakoja",
    "Shares will show up here" : "Jaot näkyvät täällä",
    "Restore" : "Palauta",
    "Restore share" : "Palauta jako",
    "Something happened. Unable to restore the share." : "Jotain tapahtui. Jakoa ei kyetty palauttamaan.",
    "Accept share" : "Hyväksy jako",
    "Reject share" : "Hylkää jako",
    "error" : "virhe",
    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
    "Move or copy" : "Siirrä tai kopioi",
    "Download" : "Lataa",
    "Delete" : "Poista",
    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
    "Terms of service" : "Käyttöehdot",
    "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
    "Invalid server URL" : "Virheellinen palvelimen URL",
    "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
    "No expiration date set" : "Ei vanhenemispäivää asetettu",
    "Shared by" : "Jakanut",
    "File shares" : "Tiedostojaot",
    "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
    "Downloaded by {email}" : "Ladannut {email}",
    "{file} downloaded via public link" : "{file} ladattu julkisen linkin kautta",
    "{email} downloaded {file}" : "{email} latasi tiedoston {file}",
    "Shared with group {group}" : "Jaettu ryhmälle {group}",
    "Removed share for group {group}" : "Lopetettu jakaminen ryhmälle {group}",
    "{actor} shared with group {group}" : "{actor} jakoi ryhmälle {group}",
    "{actor} removed share for group {group}" : "{actor} lopetti jakamisen ryhmälle {group}",
    "Share for group {group} expired" : "Jako ryhmälle {group} vanhentui",
    "You shared {file} with group {group}" : "Jaoit kohteen {file} ryhmälle {group}",
    "You removed group {group} from {file}" : "Poistit ryhmän {group} kohteen {file} käyttöoikeudet",
    "{actor} shared {file} with group {group}" : "{actor} jakoi kohteen {file} ryhmälle {group}",
    "{actor} removed group {group} from {file}" : "{actor} poisti ryhmän {group} kohteen {file} käyttöoikeudet",
    "Shared as public link" : "Jaettu julkisella linkillä",
    "Removed public link" : "Julkinen linkki poistettu",
    "Public link expired" : "Julkinen linkki vanhentui",
    "{actor} shared as public link" : "{actor} jakoi julkisena linkkinä",
    "{actor} removed public link" : "{actor} poisti julkisen linkin",
    "Public link of {actor} expired" : "Käyttäjän {actor} julkinen linkki vanheni",
    "You shared {file} as public link" : "Jaoit kohteen {file} julkisena linkkinä",
    "You removed public link for {file}" : "Poistit kohteen {file} julkisen linkin",
    "Public link expired for {file}" : "Kohteen {file} julkinen linkki vanheni",
    "{actor} shared {file} as public link" : "{actor} jakoi kohteen {file} julkisena linkkinä",
    "{actor} removed public link for {file}" : "{actor} poisti kohteen {file} julkisen linkin",
    "Public link of {actor} for {file} expired" : "Käyttäjän {actor} julkinen linkki kohteeseen {file} vanhentui",
    "{user} accepted the remote share" : "{user} hyväksyi etäjaon",
    "{user} declined the remote share" : "{user} kieltäytyi etäjaosta",
    "You received a new remote share {file} from {user}" : "Vastaanotit uuden etäjaon {file} käyttäjältä {user}",
    "{user} accepted the remote share of {file}" : "{user} hyväksyi etäjaon {file}",
    "{user} declined the remote share of {file}" : "{user} kieltäytyi etäjaosta {file}",
    "{user} unshared {file} from you" : "{user} lopetti kohteen {file} jakamisen kanssasi",
    "Shared with {user}" : "Jaettu käyttäjälle {user}",
    "Removed share for {user}" : "Poisti jaon käyttäjälle {user}",
    "You removed yourself" : "Poistit itsesi",
    "{actor} shared with {user}" : "{actor} jakoi käyttäjälle {user}",
    "{actor} removed share for {user}" : "{actor} poisti jaon käyttäjälle {user}",
    "Shared by {actor}" : "Jakanut {actor}",
    "{actor} removed share" : "{actor} lopetti jakamisen",
    "Share for {user} expired" : "Jako käyttäjälle {user} vanhentui",
    "Share expired" : "Jako vanhentui",
    "You shared {file} with {user}" : "Jaoit kohteen {file} käyttäjälle {user}",
    "You removed {user} from {file}" : "Poistit käyttäjän {user} kohteen {file} käyttöoikeudet",
    "You removed yourself from {file}" : "Poistit itsesi tiedostosta {file}",
    "{actor} shared {file} with {user}" : "{actor} jakoi kohteen {file} käyttäjälle {user}",
    "{actor} removed {user} from {file}" : "{actor} poisti käyttäjän {user} kohteen {file} käyttöoikeudet",
    "{actor} shared {file} with you" : "{actor} jakoi kohteen {file} kanssasi",
    "{actor} removed you from the share named {file}" : "{actor} poisti sinut jaosta nimeltä {file}",
    "Share for file {file} expired" : "Tiedoston {file} jako vanhentui",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Tiedosto tai kansio, joka on jaettu sähköpostitse tai julkisen linkin kautta, on <strong>ladattu</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio on jaettu <strong>toiselta palvelimelta</strong>",
    "Files" : "Tiedostot",
    "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
    "Could not delete share" : "Jaon poistaminen epäonnistui",
    "Please specify a file or folder path" : "Määritä tiedoston tai kansion polku",
    "Wrong path, file/folder doesn't exist" : "Väärä polku, tiedostoa tai kansiota ei ole olemassa",
    "Could not create share" : "Jaon luominen epäonnistui",
    "invalid permissions" : "vialliset oikeudet",
    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
    "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
    "Please specify a valid group" : "Määritä kelvollinen ryhmä",
    "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
    "Public upload disabled by the administrator" : "Ylläpitäjä on estänyt julkisen lähetyksen",
    "Public upload is only possible for publicly shared folders" : "Julkinen lähettäminen on mahdollista vain julkisesti jaetuille kansioille",
    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päivämäärän muodon tulee olla VVVV-KK-PP",
    "You cannot share to a Circle if the app is not enabled" : "Et voi jakaa piiriin, jos sovellusta ei ole aktivoitu",
    "Please specify a valid circle" : "Määritä kelvollinen piiri",
    "Unknown share type" : "Tuntematon jaon tyyppi",
    "Not a directory" : "Ei hakemisto",
    "Could not lock path" : "Polun lukitseminen ei onnistunut",
    "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
    "Can't change permissions for public share links" : "Julkisten jakolinkkien käyttöoikeuksia ei voi muuttaa",
    "shared by %s" : "%s jakama",
    "Download all files" : "Lataa kaikki tiedostot",
    "Direct link" : "Suora linkki",
    "Add to your Nextcloud" : "Lisää Nextcloudiisi",
    "Share API is disabled" : "Jakamisrajapinta on poistettu käytöstä",
    "File sharing" : "Tiedostonjako",
    "Share will expire tomorrow" : "Jako vanhenee huomenna",
    "One or more of your shares will expire tomorrow" : "Yksi tai useampi jaoistasi vanhenee huomenna",
    "Accept" : "Hyväksy",
    "Reject" : "Hylkää",
    "Sharing" : "Jakaminen",
    "Allow editing" : "Salli muokkaus",
    "Allow creating" : "Salli luominen",
    "Allow deleting" : "Salli poistaminen",
    "Allow resharing" : "Salli uudelleenjakaminen",
    "Expiration date enforced" : "Vanhenemispäivä pakotettu",
    "Set expiration date" : "Aseta vanhenemispäivä",
    "Note to recipient" : "Huomio vastaanottajalle",
    "Unshare" : "Lopeta jakaminen",
    "group" : "ryhmä",
    "conversation" : "keskustelu",
    "remote" : "etä",
    "remote group" : "etäryhmä",
    "guest" : "vieras",
    "Internal link" : "Sisäinen linkki",
    "Link copied" : "Linkki kopioitu",
    "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
    "Copy to clipboard" : "Kopioi leikepöydälle",
    "Only works for users with access to this folder" : "Toimii vain käyttäjille, joilla on oikeus tähän kansioon",
    "Password protection (enforced)" : "Salasanasuojaus (pakotettu)",
    "Password protection" : "Salasanasuojaus",
    "Enter a password" : "Syötä salasana",
    "Expiration date (enforced)" : "Vanhenemispäivä (pakotettu)",
    "Cancel" : "Peruuta",
    "Read only" : "Vain luku",
    "Allow upload and editing" : "Salli lähetys ja muokkaus",
    "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
    "Hide download" : "Piilota lataus",
    "Password protect" : "Suojaa salasanalla",
    "Add another link" : "Lisää toinen linkki",
    "Create a new share link" : "Luo uusi jakolinkki",
    "Share link" : "Jaa linkki",
    "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
    "Resharing is not allowed" : "Uudellenjako ei ole salluttu",
    "Name or email address …" : "Nimi tai sähköpostiosoite…",
    "Name …" : "Nimi…",
    "Searching …" : "Haetaan…",
    "No elements found." : "Elementtejä ei löytynyt.",
    "Search globally" : "Hae globaalisti",
    "Expires {relativetime}" : "Vanhenee {relativetime}",
    "Link to a file" : "Linkki tiedostoon",
    "Shared" : "Jaettu",
    "Share" : "Jaa",
    "Shared with" : "Jaettu",
    "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
    "Shared with you by {owner}" : "Jaettu kanssasi käyttäjältä {owner}",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Name" : "Nimi",
    "Share time" : "Jakamisen ajankohta",
    "Expiration date" : "Vanhenemispäivä",
    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
    "Reasons might be:" : "Mahdollisia syitä saattavat olla:",
    "the item was removed" : "kohde poistettiin",
    "the link expired" : "linkki vanheni",
    "sharing is disabled" : "jakaminen on poistettu käytöstä",
    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
    "Share note" : "Jaa muistiinpano",
    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
    "Download %s" : "Lataa %s",
    "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
    "Note" : "Huomio",
    "Select or drop files" : "Valitse tai pudota tiedostoja",
    "Uploaded files:" : "Lähetetyt tiedostot:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
    "could not delete share" : "jaon poistaminen epäonnistui",
    "Uploading files…" : "Lähetetään tiedostoja…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-php74-20.0.7.txz: usr/local/www/nextcloud/apps-pkg/files_sharing/l10n/fi.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Jaettu kanssasi",
    "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
    "Files and folders others share with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
    "Shared with others" : "Jaettu muiden kanssa",
    "Nothing shared yet" : "Ei mitään jaettua",
    "Files and folders you share will show up here" : "Jakamasi tiedostot ja kansiot näkyvät täällä",
    "Shared by link" : "Jaettu linkin kautta",
    "No shared links" : "Ei jaettuja linkkejä",
    "Files and folders you share by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
    "Deleted shares" : "Poistetut jaot",
    "No deleted shares" : "Ei poistettuja jakoja",
    "Shares you deleted will show up here" : "Poistamasi jaot näkyvät täällä",
    "Pending shares" : "Odottavat jaot",
    "No pending shares" : "Ei odottavia jakoja",
    "Shares you have received but not confirmed will show up here" : "Vastaanottamasi jaot, joita ei ole vahvistettu, näkyvät täällä",
    "Shares" : "Jaot",
    "No shares" : "Ei jakoja",
    "Shares will show up here" : "Jaot näkyvät täällä",
    "Restore" : "Palauta",
    "Restore share" : "Palauta jako",
    "Something happened. Unable to restore the share." : "Jotain tapahtui. Jakoa ei kyetty palauttamaan.",
    "Accept share" : "Hyväksy jako",
    "Something happened. Unable to accept the share." : "Jotain tapahtui. Jakoa ei voitu hyväksyä.",
    "Reject share" : "Hylkää jako",
    "Something happened. Unable to reject the share." : "Tapahtui virhe. Ei voida hylätä jakoa.",
    "Waiting…" : "Odotetaan…",
    "error" : "virhe",
    "finished" : "valmis",
    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
    "Move or copy" : "Siirrä tai kopioi",
    "Download" : "Lataa",
    "Delete" : "Poista",
    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
    "Terms of service" : "Käyttöehdot",
    "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
    "Invalid server URL" : "Virheellinen palvelimen URL",
    "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
    "No expiration date set" : "Ei vanhenemispäivää asetettu",
    "Shared by" : "Jakanut",
    "File shares" : "Tiedostojaot",
    "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
    "Downloaded by {email}" : "Ladannut {email}",
    "{file} downloaded via public link" : "{file} ladattu julkisen linkin kautta",
    "{email} downloaded {file}" : "{email} latasi tiedoston {file}",
    "Shared with group {group}" : "Jaettu ryhmälle {group}",
    "Removed share for group {group}" : "Lopetettu jakaminen ryhmälle {group}",
    "{actor} shared with group {group}" : "{actor} jakoi ryhmälle {group}",
    "{actor} removed share for group {group}" : "{actor} lopetti jakamisen ryhmälle {group}",
    "Share for group {group} expired" : "Jako ryhmälle {group} vanhentui",
    "You shared {file} with group {group}" : "Jaoit kohteen {file} ryhmälle {group}",
    "You removed group {group} from {file}" : "Poistit ryhmän {group} kohteen {file} käyttöoikeudet",
    "{actor} shared {file} with group {group}" : "{actor} jakoi kohteen {file} ryhmälle {group}",
    "{actor} removed group {group} from {file}" : "{actor} poisti ryhmän {group} kohteen {file} käyttöoikeudet",
    "Share for file {file} with group {group} expired" : "Tiedoston {file} jako ryhmän {group} kanssa on päättynyt",
    "Shared as public link" : "Jaettu julkisella linkillä",
    "Removed public link" : "Julkinen linkki poistettu",
    "Public link expired" : "Julkinen linkki vanhentui",
    "{actor} shared as public link" : "{actor} jakoi julkisena linkkinä",
    "{actor} removed public link" : "{actor} poisti julkisen linkin",
    "Public link of {actor} expired" : "Käyttäjän {actor} julkinen linkki vanheni",
    "You shared {file} as public link" : "Jaoit kohteen {file} julkisena linkkinä",
    "You removed public link for {file}" : "Poistit kohteen {file} julkisen linkin",
    "Public link expired for {file}" : "Kohteen {file} julkinen linkki vanheni",
    "{actor} shared {file} as public link" : "{actor} jakoi kohteen {file} julkisena linkkinä",
    "{actor} removed public link for {file}" : "{actor} poisti kohteen {file} julkisen linkin",
    "Public link of {actor} for {file} expired" : "Käyttäjän {actor} julkinen linkki kohteeseen {file} vanhentui",
    "{user} accepted the remote share" : "{user} hyväksyi etäjaon",
    "{user} declined the remote share" : "{user} kieltäytyi etäjaosta",
    "You received a new remote share {file} from {user}" : "Vastaanotit uuden etäjaon {file} käyttäjältä {user}",
    "{user} accepted the remote share of {file}" : "{user} hyväksyi etäjaon {file}",
    "{user} declined the remote share of {file}" : "{user} kieltäytyi etäjaosta {file}",
    "{user} unshared {file} from you" : "{user} lopetti kohteen {file} jakamisen kanssasi",
    "Shared with {user}" : "Jaettu käyttäjälle {user}",
    "Removed share for {user}" : "Poisti jaon käyttäjälle {user}",
    "You removed yourself" : "Poistit itsesi",
    "{actor} removed themselves" : "{actor} poisti itsensä",
    "{actor} shared with {user}" : "{actor} jakoi käyttäjälle {user}",
    "{actor} removed share for {user}" : "{actor} poisti jaon käyttäjälle {user}",
    "Shared by {actor}" : "Jakanut {actor}",
    "{actor} removed share" : "{actor} lopetti jakamisen",
    "Share for {user} expired" : "Jako käyttäjälle {user} vanhentui",
    "Share expired" : "Jako vanhentui",
    "You shared {file} with {user}" : "Jaoit kohteen {file} käyttäjälle {user}",
    "You removed {user} from {file}" : "Poistit käyttäjän {user} kohteen {file} käyttöoikeudet",
    "You removed yourself from {file}" : "Poistit itsesi tiedostosta {file}",
    "{actor} removed themselves from {file}" : "{actor} poisti itsensä tiedostosta {file}",
    "{actor} shared {file} with {user}" : "{actor} jakoi kohteen {file} käyttäjälle {user}",
    "{actor} removed {user} from {file}" : "{actor} poisti käyttäjän {user} kohteen {file} käyttöoikeudet",
    "{actor} shared {file} with you" : "{actor} jakoi kohteen {file} kanssasi",
    "{actor} removed you from the share named {file}" : "{actor} poisti sinut jaosta nimeltä {file}",
    "Share for file {file} with {user} expired" : "Tiedoston {file} jako käyttäjän {user} kanssa on päättynyt",
    "Share for file {file} expired" : "Tiedoston {file} jako vanhentui",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Tiedosto tai kansio, joka on jaettu sähköpostitse tai julkisen linkin kautta, on <strong>ladattu</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio on jaettu <strong>toiselta palvelimelta</strong>",
    "Files" : "Tiedostot",
    "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
    "Shared link" : "Jaettu linkki",
    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
    "Could not delete share" : "Jaon poistaminen epäonnistui",
    "Please specify a file or folder path" : "Määritä tiedoston tai kansion polku",
    "Wrong path, file/folder doesn't exist" : "Väärä polku, tiedostoa tai kansiota ei ole olemassa",
    "Could not create share" : "Jaon luominen epäonnistui",
    "invalid permissions" : "vialliset oikeudet",
    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
    "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
    "Please specify a valid group" : "Määritä kelvollinen ryhmä",
    "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
    "Public upload disabled by the administrator" : "Ylläpitäjä on estänyt julkisen lähetyksen",
    "Public upload is only possible for publicly shared folders" : "Julkinen lähettäminen on mahdollista vain julkisesti jaetuille kansioille",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Kohteen %s jakaminen lähettämällä salasana Nextcloud Talkin kautta epäonnistui, koska Nextcloud Talk ei ole käytössä",
    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päivämäärän muodon tulee olla VVVV-KK-PP",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Kohteen %1$s jakaminen epäonnistui, koska tietovarasto ei salli %2$s tyyppisiä jakoja",
    "You cannot share to a Circle if the app is not enabled" : "Et voi jakaa piiriin, jos sovellusta ei ole aktivoitu",
    "Please specify a valid circle" : "Määritä kelvollinen piiri",
    "Unknown share type" : "Tuntematon jaon tyyppi",
    "Not a directory" : "Ei hakemisto",
    "Could not lock path" : "Polun lukitseminen ei onnistunut",
    "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
    "Can't change permissions for public share links" : "Julkisten jakolinkkien käyttöoikeuksia ei voi muuttaa",
    "shared by %s" : "%s jakama",
    "Download all files" : "Lataa kaikki tiedostot",
    "Direct link" : "Suora linkki",
    "Add to your Nextcloud" : "Lisää Nextcloudiisi",
    "Share API is disabled" : "Jakamisrajapinta on poistettu käytöstä",
    "File sharing" : "Tiedostonjako",
    "Share will expire tomorrow" : "Jako vanhenee huomenna",
    "One or more of your shares will expire tomorrow" : "Yksi tai useampi jaoistasi vanhenee huomenna",
    "You received {share} as a share by {user}" : "Vastaanotit jaon {share} käyttäjältä {user}",
    "You received {share} to group {group} as a share by {user}" : "Vastaanotit jaon {share} ryhmään {group} käyttäjältä {user}",
    "Accept" : "Hyväksy",
    "Reject" : "Hylkää",
    "Sharing" : "Jakaminen",
    "Accept user and group shares by default" : "Hyväksy käyttäjä- ja ryhmäjaot oletuksena",
    "Allow editing" : "Salli muokkaus",
    "Allow creating" : "Salli luominen",
    "Allow deleting" : "Salli poistaminen",
    "Allow resharing" : "Salli uudelleenjakaminen",
    "Expiration date enforced" : "Vanhenemispäivä pakotettu",
    "Set expiration date" : "Aseta vanhenemispäivä",
    "Enter a date" : "Syötä päivämäärä",
    "Note to recipient" : "Huomio vastaanottajalle",
    "Unshare" : "Lopeta jakaminen",
    "group" : "ryhmä",
    "conversation" : "keskustelu",
    "remote" : "etä",
    "remote group" : "etäryhmä",
    "guest" : "vieras",
    "Shared with the group {user} by {owner}" : "Jaettu ryhmän {user} kanssa käyttäjältä {owner}",
    "Shared with the conversation {user} by {owner}" : "Jaettu keskustelun {user} kanssa käyttäjältä {owner}",
    "Shared with {user} by {owner}" : "{owner} jakoi käyttäjälle {user}",
    "Added by {initiator}" : "Lisäyksen tehnyt {initiator}",
    "Via “{folder}”" : "“{folder}” kautta",
    "Internal link" : "Sisäinen linkki",
    "Link copied" : "Linkki kopioitu",
    "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
    "Copy to clipboard" : "Kopioi leikepöydälle",
    "Only works for users with access to this folder" : "Toimii vain käyttäjille, joilla on oikeus tähän kansioon",
    "Only works for users with access to this file" : "Toimii vain käyttäjille, joilla on käyttöoikeus tähän tiedostoon",
    "Please enter the following required information before creating the share" : "Anna seuraavat vaaditut tiedot, ennen kuin luot jaon",
    "Password protection (enforced)" : "Salasanasuojaus (pakotettu)",
    "Password protection" : "Salasanasuojaus",
    "Enter a password" : "Syötä salasana",
    "Expiration date (enforced)" : "Vanhenemispäivä (pakotettu)",
    "Create share" : "Luo jako",
    "Cancel" : "Peruuta",
    "Share label" : "Jaon nimi",
    "Read only" : "Vain luku",
    "Allow upload and editing" : "Salli lähetys ja muokkaus",
    "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
    "Hide download" : "Piilota lataus",
    "Password protect" : "Suojaa salasanalla",
    "Video verification" : "Videovarmistus",
    "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
    "Add another link" : "Lisää toinen linkki",
    "Create a new share link" : "Luo uusi jakolinkki",
    "Shared via link by {initiator}" : "Jaettu linkin kautta käyttäjältä {initiator}",
    "Share link ({label})" : "Jaa linkki ({label})",
    "Share link" : "Jaa linkki",
    "Error, please enter proper password and/or expiration date" : "Virhe, lisää kelvollinen salasana ja/tai päättymispäivä",
    "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
    "Resharing is not allowed" : "Uudellenjako ei ole salluttu",
    "Name or email …" : "Nimi tai sähköposti...",
    "Name, email, or Federated Cloud ID …" : "Nimi, sähköposti tai federoitu Cloud ID...",
    "Searching …" : "Haetaan…",
    "No elements found." : "Elementtejä ei löytynyt.",
    "Search globally" : "Hae globaalisti",
    "on {server}" : "palvelimella {server}",
    "Others with access" : "Muut, joilla on käyttöoikeus",
    "No other users with access found" : "Ei löytynyt muita käyttäjiä, joilla olisi käyttöoikeus",
    "Toggle list of others with access to this directory" : "Vaihda näkymää kansioon käyttöoikeuden omaavista käyttäjistä",
    "Toggle list of others with access to this file" : "Vaihda näkymää tiedostoon käyttöoikeuden omaavista käyttäjistä",
    "Unable to load the shares list" : "Jakolistan haku epäonnistui",
    "Expires {relativetime}" : "Vanhenee {relativetime}",
    "this share just expired." : "tämä jako vanheni juuri.",
    "Link to a file" : "Linkki tiedostoon",
    "Error creating the share" : "Virhe jakoa luotaessa",
    "Error updating the share" : "Virhe jakoa päivittäessä",
    "Shared" : "Jaettu",
    "Share" : "Jaa",
    "Shared with" : "Jaettu",
    "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
    "Shared with you and {circle} by {owner}" : "{owner} on jakanut tämän sinun ja piirin {circle} kanssa",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} on jakanut tämän sinun ja keskustelun {conversation} kanssa",
    "Shared with you in a conversation by {owner}" : "{owner} jakoi tämän kanssasi keskustelussa",
    "Shared with you by {owner}" : "{owner} jakoi tämän kanssasi",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Name" : "Nimi",
    "Share time" : "Jakamisen ajankohta",
    "Expiration date" : "Vanhenemispäivä",
    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
    "Reasons might be:" : "Mahdollisia syitä saattavat olla:",
    "the item was removed" : "kohde poistettiin",
    "the link expired" : "linkki vanheni",
    "sharing is disabled" : "jakaminen on poistettu käytöstä",
    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
    "Share note" : "Jaa muistiinpano",
    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
    "Download %s" : "Lataa %s",
    "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
    "Note" : "Huomio",
    "Select or drop files" : "Valitse tai pudota tiedostoja",
    "Uploading files" : "Lähetetään tiedostoja",
    "Uploaded files:" : "Lähetetyt tiedostot:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
    "Name, email, or federated cloud ID …" : "Nimi, sähköposti tai federoitu Cloud ID..."
},
"nplurals=2; plural=(n != 1);");
